@@ -211,12 +211,12 @@ db_pager_parse (YelpPager *pager)
 {
     YelpDBPagerPriv *priv;
     YelpDocInfo     *doc_info;
-    gchar           *filename;
+    gchar           *filename = NULL;
 
-    xmlParserCtxtPtr parserCtxt;
-    xmlDocPtr doc;
+    xmlParserCtxtPtr parserCtxt = NULL;
+    xmlDocPtr doc = NULL;
 
-    DBWalker    *walker;
+    DBWalker    *walker = NULL;
     xmlChar     *id;
     GError      *error = NULL;
 
@@ -277,10 +277,13 @@ db_pager_parse (YelpPager *pager)
     walker_walk_xml (walker);
 
  done:
-    xsltFreeStylesheet (walker->titleStylesheet);
+    if (walker) {
+	if (walker->titleStylesheet)
+	    xsltFreeStylesheet (walker->titleStylesheet);
+	g_free (walker);
+    }
 
     g_free (filename);
-    g_free (walker);
 
     if (parserCtxt)
 	xmlFreeParserCtxt (parserCtxt);
@@ -386,11 +389,11 @@ walker_walk_xml (DBWalker *walker)
 {
     xmlChar     *id    = NULL;
     xmlChar     *title = NULL;
-    gchar       *old_id;
+    gchar       *old_id = NULL;
     xmlNodePtr   cur;
     xmlNodePtr   old_cur;
     GtkTreeIter  iter;
-    GtkTreeIter *old_iter;
+    GtkTreeIter *old_iter = NULL;
     YelpDBPagerPriv *priv = walker->pager->priv;
 
     if (walker->depth == 0) {
@@ -487,8 +490,8 @@ node_get_title (DBWalker *walker)
     doc = xsltApplyStylesheet (walker->titleStylesheet,
 			       walker->doc,
 			       (const char **)params);
-    if (xsltSaveResultToString (&outstr, &outlen, doc, walker->titleStylesheet) < 0)
-	title = _("Unknown Section");
+    if (doc == NULL || xsltSaveResultToString (&outstr, &outlen, doc, walker->titleStylesheet) < 0)
+	title = g_strdup (_("Unknown Section"));
     else {
 	title = g_strdup (outstr);
 	xmlFree (outstr);
